@@ -218,10 +218,10 @@ function getLDAPData($sender,$resource)
       if( $dn ) {
 	// Sender is local, check for groups
 	foreach( $policies as $gid => $policy ) {
-	  list($cn, $domain) = split( '@', $gid );
+	  list($gcn, $domain) = split( '@', $gid );
 	  if( $domain != $params['email_domain'] ) continue;
 	  $result = ldap_search($ldap, $params['base_dn'],
-				"(&(objectClass=kolabGroupOfNames)(cn=$cn)(member=$dn))",
+				"(&(objectClass=kolabGroupOfNames)(cn=$gcn)(member=$dn))",
 				array('dn'));
 	  if (!$result) {
 	    myLog('Unable to perform LDAP search: ' . ldap_error($ldap));
@@ -691,10 +691,75 @@ function expire_events( $imap, $when )
   // normal user accounts
 }
 
-function iCalDate2Kolab($ical_date)
+// resource error when date is used and no timestring
+
+function cleanArray($ical_date)
 {
+	if ( array_key_exists('hour',$ical_date) ) {
+		$temp['hour']   = array_key_exists('hour',$ical_date) ? $ical_date['hour'] :  '00';
+		$temp['minute']   = array_key_exists('minute',$ical_date) ? $ical_date['minute'] :  '00';
+		$temp['second']   = array_key_exists('second',$ical_date) ? $ical_date['second'] :  '00';
+		$temp['zone']   = array_key_exists('zone',$ical_date) ? $ical_date['zone'] :  'UTC';
+	} else { 
+		$temp['DATE'] = '1';
+	}
+	$temp['year']   = array_key_exists('year',$ical_date) ? $ical_date['year'] :  '0000';
+	$temp['month']   = array_key_exists('month',$ical_date) ? $ical_date['month'] :  '00';
+	$temp['mday']   = array_key_exists('mday',$ical_date) ? $ical_date['mday'] :  '00';
+
+	return $temp;
+}
+
+
+
+/*
+
+An all day event must have a dd--mm-yyyy notation and not a yyyy-dd-mmT00:00:00z notation
+Otherwise the event is shown as a 2-day event
+--> do not try to convert everything to epoch first !!
+*/
+
+function iCalDate2Kolab($ical_date,$type= ' ')
+{
+    myLog("Converting to kolab format ".print_r($ical_date,true),RM_LOG_DEBUG);
     // $ical_date should be a timestamp
-    return gmstrftime('%Y-%m-%dT%H:%M:%SZ', $ical_date);
+    if (is_array($ical_date)) {
+	# going to create date again
+	$temp=cleanArray($ical_date);
+    	if (array_key_exists('DATE',$temp)) {
+		if ($type == 'ENDDATE') {
+			# substract a day (86400 seconds) using epochs to take number of days per month into account
+			$epoch=convert2epoch($temp)-86400;
+        		$date = gmstrftime('%Y-%m-%d', $epoch);
+		} else {
+		    	$date= sprintf('%04d-%02d-%02d',$temp['year'], $temp['month'], $temp['mday']);
+		}
+	} else {
+		$time = sprintf('%02d:%02d:%02d', $temp['hour'], $temp['minute'], $temp['second']);
+	        if ($temp['zone'] == 'UTC') {
+        	    $time .= 'Z';
+        	}
+        	$date= sprintf('%04d-%02d-%02d',$temp['year'], $temp['month'], $temp['mday']). "T".$time;
+	}
+    }  else {
+        $date = gmstrftime('%Y-%m-%dT%H:%M:%SZ', $ical_date);
+    }
+    myLog("To <$date>",RM_LOG_DEBUG);
+     return $date;
+}
+
+
+function convert2epoch($values)
+{
+    myLog("Converting to epoch ".print_r($values,true),RM_LOG_DEBUG);
+
+    if (is_array($values)) {
+	$temp=cleanArray($values);
+	$epoch=gmmktime($temp['hour'],$temp['minute'],$temp['second'],$temp['month'],$temp['mday'],$temp['year']);
+    } else { $epoch=$values;} 
+    
+    myLog("Converted <$epoch>",RM_LOG_DEBUG);
+    return $epoch;
 }
 
 function &buildKolabEvent(&$itip)
@@ -752,8 +817,14 @@ function &buildKolabEvent(&$itip)
 
     $kolab_node = $kolab_event->append_child($kolab_xml->create_element('end-date'));
     $kolab_node->append_child($kolab_xml->create_text_node(
-        iCalDate2Kolab($itip->getAttributeDefault('DTEND', 0))
+        iCalDate2Kolab($itip->getAttributeDefault('DTEND', 0),'ENDDATE')
     ));
+
+    # default is busy, so set free if info is available
+    if ($itip->getAttributeDefault('TRANSP', 'OPAQUE') == 'TRANSPARENT') {
+	$kolab_node = $kolab_event->append_child($kolab_xml->create_element('show-time-as'));
+	$kolab_node->append_child($kolab_xml->create_text_node('free' ));
+   }
     
     // Attendees
     $attendees = $itip->getAttribute('ATTENDEE');
@@ -836,8 +907,8 @@ function &buildKolabEvent(&$itip)
       $freq = strtolower($rrule['FREQ']);
       $recur_node->append_child( $kolab_xml->create_attribute( 'cycle', $freq ));
       $recurrence->setCycletype( $freq );
-      $recurrence->setStartdate( $itip->getAttributeDefault('DTSTART', 0) );
-      $recurrence->setEnddate( $itip->getAttributeDefault('DTEND', 0) );
+      $recurrence->setStartdate( convert2epoch($itip->getAttributeDefault('DTSTART', 0)) );
+      $recurrence->setEnddate( convert2epoch($itip->getAttributeDefault('DTEND', 0) ));
       switch( $freq ) {
       case 'daily':
 	break;
@@ -967,7 +1038,7 @@ function &buildKolabEvent(&$itip)
 	$recurrence->setRange( $rrule['COUNT']);
       } else if( $rrule['UNTIL'] ) {
 	$range_node->append_child( $kolab_xml->create_attribute( 'type', 'date' ));      
-	$range_node->append_child($kolab_xml->create_text_node($rrule['UNTIL']));
+	$range_node->append_child($kolab_xml->create_text_node(gmstrftime('%Y-%m-%d', $itip->_parseDateTime($rrule['UNTIL']))));
 	$recurrence->setRangetype('date');
 	$recurrence->setRange( $rrule['UNTIL']);
       } else {
@@ -1045,6 +1116,7 @@ function resmgr_filter( $fqhostname, $sender, $resource, $tmpfname ) {
   $iCalendar = &getICal($sender,$resource);
   if( $iCalendar === false ) {
     // No iCal in mail
+    myLog("Could not parse iCalendar data, Passing through to $resource");
     return true;
   }
   // Get the event details out of the iTip request
@@ -1074,11 +1146,11 @@ function resmgr_filter( $fqhostname, $sender, $resource, $tmpfname ) {
   // What is the events summary?
   $summary = $itip->getAttributeDefault('SUMMARY', '');
 
-  $dtstart = $itip->getAttributeDefault('DTSTART', 0);
-  $dtend = $itip->getAttributeDefault('DTEND', 0);
+  $dtstart = convert2epoch ($itip->getAttributeDefault('DTSTART', 0));
+  $dtend = convert2epoch ($itip->getAttributeDefault('DTEND', 0));
 
-  myLog('Event starts on ' . strftime('%a, %d %b %Y %H:%M:%S %z', $dtstart) .
-	' and ends on ' . strftime('%a, %d %b %Y %H:%M:%S %z', $dtend), RM_LOG_DEBUG);
+  myLog("Event starts on <$dtstart> " .iCalDate2Kolab($dtstart).
+	" and ends on <$dtend> " . iCalDate2Kolab($dtend), RM_LOG_DEBUG);
 
   if ($params['action'] == RM_ACT_ALWAYS_REJECT) {
     myLog("Rejecting $method method");
@@ -1131,34 +1203,41 @@ function resmgr_filter( $fqhostname, $sender, $resource, $tmpfname ) {
 
       $vfbstart = $vfb->getAttributeDefault('DTSTART', 0);
       $vfbend = $vfb->getAttributeDefault('DTEND', 0);
-      myLog('Free/busy info starts on ' . strftime('%a, %d %b %Y %H:%M:%S %z', $vfbstart) .
-	    ' and ends on ' . strftime('%a, %d %b %Y %H:%M:%S %z', $vfbend), RM_LOG_DEBUG);
-
-      // Check whether we are busy or not
-      $busyperiods = $vfb->getBusyPeriods();
-      $extraparams = $vfb->getExtraParams();
-      $conflict = false;	    
-      if( $recurrence !== false ) {
-	$recurrence->busyperiods =& $busyperiods;
-	$recurrence->extraparams =& $extraparams;
-	$recurrence->ignore = $ignore;
-	//myLog("Recurrence is ".print_r($recurrence,true), RM_LOG_DEBUG);
-	$recurrence->expand( $vfbstart, $vfbend );
-	$conflict = $recurrence->hasConflict();
-      } else {	    
-	foreach ($busyperiods as $busyfrom => $busyto) {
-	  myLog('Busy period from ' . strftime('%a, %d %b %Y %H:%M:%S %z', $busyfrom) . ' to ' . strftime('%a, %d %b %Y %H:%M:%S %z', $busyto), RM_LOG_DEBUG);
-	  if ( in_array(base64_decode($extraparams[$busyfrom]['X-UID']), $ignore) ||
-	       in_array(base64_decode($extraparams[$busyfrom]['X-SID']), $ignore) ) {
-	    // Ignore
-	    continue;
-	  }
-	  if (($busyfrom >= $dtstart && $busyfrom < $dtend) || ($dtstart >= $busyfrom && $dtstart < $busyto)) {
-	    myLog('Request overlaps', RM_LOG_DEBUG);
-	    $conflict = true;
-	    break;
-	  }
-	}
+      myLog("Free/busy info starts on <$vfbstart>" .iCalDate2Kolab($vfbstart) .
+	    " and ends on <$fbend>" .iCalDate2Kolab($vfbend), RM_LOG_DEBUG);
+	
+      $outofperiod=0;
+      if ($dtstart > convert2epoch ($vfbend)) {
+		$outofperiod=1;
+      } else {
+	      // Check whether we are busy or not
+	      $busyperiods = $vfb->getBusyPeriods();
+	      myLog("Busyperiods: ".print_r($busyperiods,true),RM_LOG_DEBUG);
+	      $extraparams = $vfb->getExtraParams();
+	      myLog("Extraparams: ".print_r($extraparams,true),RM_LOG_DEBUG);
+	      $conflict = false;	    
+	      if( $recurrence !== false ) {
+		$recurrence->busyperiods =& $busyperiods;
+		$recurrence->extraparams =& $extraparams;
+		$recurrence->ignore = $ignore;
+		myLog("Recurrence is ".print_r($recurrence,true), RM_LOG_DEBUG);
+		$recurrence->expand( $vfbstart, $vfbend );
+		$conflict = $recurrence->hasConflict();
+	      } else {	    
+		foreach ($busyperiods as $busyfrom => $busyto) {
+		  myLog('Busy period from ' . strftime('%a, %d %b %Y %H:%M:%S %z', $busyfrom) . ' to ' . strftime('%a, %d %b %Y %H:%M:%S %z', $busyto), RM_LOG_DEBUG);
+		  if ( in_array(base64_decode($extraparams[$busyfrom]['X-UID']), $ignore) ||
+		       in_array(base64_decode($extraparams[$busyfrom]['X-SID']), $ignore) ) {
+		    // Ignore
+		    continue;
+		  }
+		  if (($busyfrom >= $dtstart && $busyfrom < $dtend) || ($dtstart >= $busyfrom && $dtstart < $busyto)) {
+		    myLog('Request overlaps', RM_LOG_DEBUG);
+		    $conflict = true;
+		    break;
+		  }
+		}
+	      }
       }
 
       if ($conflict) {
@@ -1242,7 +1321,12 @@ function resmgr_filter( $fqhostname, $sender, $resource, $tmpfname ) {
       $itip->setAttribute('ATTENDEE', $attendee, $attparams[$i]);
     }
 
-    sendITipReply($cn,$resource,$itip,RM_ITIP_ACCEPT);
+    if ($outofperiod) {
+       sendITipReply($cn,$resource,$itip,RM_ITIP_TENTATIVE);
+       myLog("No freebusy information available", RM_LOG_NOTICE);
+    } else {
+       sendITipReply($cn,$resource,$itip,RM_ITIP_ACCEPT);
+    }
 
     // Delete any old events that we updated
     if( !empty( $updated_messages ) ) {
@@ -1346,10 +1430,8 @@ function resmgr_filter( $fqhostname, $sender, $resource, $tmpfname ) {
   default:
     // We either don't currently handle these iTip methods, or they do not
     // apply to what we're trying to accomplish here
-    if (!$params['group']) {
-      myLog("Ignoring $method method");
-      return false;
-    }
+    myLog("Ignoring $method method and passing message through to $resource");
+    return true;
   }
 
   // Pass the message through to the group's mailbox
